==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        get_up() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return WilliamsPercentRIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.vb));
        }
        set va(a) {
            this.h(WilliamsPercentRIndicator.vb, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
    }
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.vb = StrategyBasedIndicator.u7(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return WilliamsPercentRIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.zk));
        }
        set zj(a) {
            this.h(WilliamsPercentRIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.zk = StrategyBasedIndicator.zg(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();
